@@ -5,13 +5,15 @@ import RPi.GPIO as GPIO
 
 class Light(object):
     def __init__(self):
-        GPIO.setmode(GPIO.BOARD)
-        GPIO.setup(33, GPIO.IN)
+        pass
 
     @staticmethod
     # false means shiny
     def shiny_or_dark():
-        input_value = GPIO.input(33)
+        GPIO.setmode(GPIO.BCM)
+        GPIO.setup(13, GPIO.IN)
+        input_value = GPIO.input(13)
+        GPIO.cleanup()
         return input_value
 
 
